spMax property

double get spMax

Largest of the raw value and its scaled font size counterpart. Useful to avoid text getting smaller than a specified minimum.

Implementation

double get spMax => max(toDouble(), sp);