Responsive class
Layout builder that chooses the appropriate UI for the active DeviceType.
It evaluates the current width via ResponsiveUtils.setDeviceType and then
calls one of the provided builders. Fallback order when a builder is null:
mobile -> tablet -> desktop.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- Responsive
- Annotations
-
- @Deprecated('Use ResponsiveScope.value() from v2 API instead. ' 'v1 will be removed in a future major release.')
Constructors
- Responsive({Key? key, Widget mobileSmall(BoxConstraints constraints)?, Widget mobile(BoxConstraints constraints)?, Widget tabletSmall(BoxConstraints constraints)?, Widget tablet(BoxConstraints constraints)?, Widget desktop(BoxConstraints constraints)?, Widget desktopLarge(BoxConstraints constraints)?})
-
const
Properties
- desktop → Widget Function(BoxConstraints constraints)?
-
Builder for large screens (desktop/web).
final
- desktopLarge → Widget Function(BoxConstraints constraints)?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- mobile → Widget Function(BoxConstraints constraints)?
-
final
- mobileSmall → Widget Function(BoxConstraints constraints)?
-
Builder for small screens (phones).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tablet → Widget Function(BoxConstraints constraints)?
-
final
- tabletSmall → Widget Function(BoxConstraints constraints)?
-
Builder for medium screens (tablets/foldables).
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited